@@ -13,6 +13,6 @@ unittestreport基于unittest扩展了5个功能：
 5、多线程执行测试用例
 """
 
-from unittestreport.core.testRunner import TestRunner
+from .core.testRunner import TestRunner,Load
 from .core.dataDriver import ddt, list_data, json_data, yaml_data
 from .core.reRun import rerun
